@@ -293,18 +293,16 @@ Ionizable::ionize()
 
   Formula formula(m_ionizeRule.formula());
 
+  qDebug() << "The formula right before ionizing:" << formula.toString();
+
   Ponderable temp(*this);
 
-  // qDebug() << __FILE__ << __LINE__
-  //          << "Before ionization:\n"
-  //          << "Ionizable's charge / level:"
-  //          << m_ionizeRule.charge() << "/" <<  m_ionizeRule.level()
-  //          << " -- "
-  //          << "Ionizable's whole charge:"
-  //          << m_ionizeRule.charge() * m_ionizeRule.level()
-  //          << " -- "
-  //          << "Mono:" << temp.mono() << "Avg:" << temp.avg()
-  //          << "\n\n";
+  qDebug() << __FILE__ << __LINE__ << "Before ionization:\n"
+           << "Ionizable's charge / level:" << m_ionizeRule.charge() << "/"
+           << m_ionizeRule.level() << " -- "
+           << "Ionizable's whole charge:"
+           << m_ionizeRule.charge() * m_ionizeRule.level() << " -- "
+           << "Mono:" << temp.mono() << "Avg:" << temp.avg() << "\n\n";
 
   double localMono = 0;
   double localAvg  = 0;
@@ -318,6 +316,10 @@ Ionizable::ionize()
        isotopic_data_csp, &localMono, &localAvg, m_ionizeRule.level()))
     return -1;
 
+  qDebug() << qSetRealNumberPrecision(6)
+           << "Right after accounting formula masses:" << localAvg << "-"
+           << localMono;
+
   // OK, the accounting of the masses worked ok, we can update the
   // values in the mono and avg params(note that we know that the
   // charge and level values of m_ionizeRule cannot be <= 0 because
@@ -325,6 +327,11 @@ Ionizable::ionize()
 
   int ionCharge = m_ionizeRule.charge() * m_ionizeRule.level();
 
+  qDebug() << "The ion charge:" << ionCharge;
+
+  qDebug() << qSetRealNumberPrecision(6) << "m_mono:" << m_mono
+           << "m_avg:" << m_avg;
+
   m_mono += localMono;
   m_mono = m_mono / ionCharge;
 
@@ -334,16 +341,12 @@ Ionizable::ionize()
   // Of course, we now are ionized.
   m_isIonized = true;
 
-  // qDebug() << __FILE__ << __LINE__
-  //          << "After ionization:\n"
-  //          << "Ionizable's charge / level:"
-  //          << m_ionizeRule.charge() << "/" <<  m_ionizeRule.level()
-  //          << " -- "
-  //          << "Ionizable's whole charge:"
-  //          << m_ionizeRule.charge() * m_ionizeRule.level()
-  //          << " -- "
-  //          << "Mono:" << m_mono << "Avg:" << m_avg
-  //          << "\n\n";
+  qDebug() << __FILE__ << __LINE__ << "After ionization:\n"
+           << "Ionizable's charge / level:" << m_ionizeRule.charge() << "/"
+           << m_ionizeRule.level() << " -- "
+           << "Ionizable's whole charge:"
+           << m_ionizeRule.charge() * m_ionizeRule.level() << " -- "
+           << "Mono:" << m_mono << "Avg:" << m_avg << "\n\n";
 
   // If something changed in the masses, then return 1, otherwise
   // return 0.
@@ -388,19 +391,30 @@ Ionizable::ionize(const IonizeRule &ionizeRule)
 
   Ponderable temp(*this);
 
+
   if(m_isIonized)
     {
+      qDebug() << "this before deionization:" << toString();
+
       if(!deionize())
         return -1;
       else
         // Make clear that at this point we are not ionized.
         m_isIonized = false;
+
+      qDebug() << "this after deionization:" << toString();
+    }
+  else
+    {
+      qDebug() << "this is not ionized:" << toString();
     }
 
   // At this point perform the ionization proper using 'ionizeRule'.
 
   Formula formula(ionizeRule.formula());
 
+  qDebug() << "The ionization formula is:" << formula.toString();
+
   double localMono = 0;
   double localAvg  = 0;
 
@@ -412,14 +426,27 @@ Ionizable::ionize(const IonizeRule &ionizeRule)
        isotopic_data_csp, &localMono, &localAvg, ionizeRule.level()))
     return -1;
 
+  qDebug() << qSetRealNumberPrecision(6)
+           << "Right after accounting the ionization masses:" << localMono
+           << "-" << localAvg;
+
   // OK, the accounting of the masses worked ok, we can update the
   // values in the mono and avg params(note that we know that the
   // charge and level values of ionizeRule cannot be <= 0 because
   // otherwise the ionizRule would not have validated.
 
+  qDebug()
+    << qSetRealNumberPrecision(6)
+    << "The ionizable masses before addition of the masses due to ionization:"
+    << m_mono << "-" << m_avg;
+
   m_mono += localMono;
   m_avg += localAvg;
 
+  qDebug() << qSetRealNumberPrecision(6)
+           << "Right after having added the ionization masses:" << m_mono << "-"
+           << m_avg;
+
   // If the ionization rule is for actually ionizing, then perform
   // the division.
   if(ionizeRule.level())
@@ -427,6 +454,9 @@ Ionizable::ionize(const IonizeRule &ionizeRule)
       m_mono = m_mono / (ionizeRule.charge() * ionizeRule.level());
       m_avg  = m_avg / (ionizeRule.charge() * ionizeRule.level());
 
+      qDebug() << qSetRealNumberPrecision(6)
+               << "And now true m/z values:" << m_mono << "-" << m_avg;
+
       m_isIonized = true;
     }
   else
@@ -573,6 +603,9 @@ Ionizable::deionize()
 
   Ponderable temp(*this);
 
+  qDebug() << "this before deionizing:" << toString();
+
+
   // At this point we know the Ionizable is ionized, thus it is an
   // error that m_ionizeRule is not valid.
 
@@ -583,10 +616,16 @@ Ionizable::deionize()
 
   double localMono = m_mono * abs(m_ionizeRule.charge() * m_ionizeRule.level());
 
+  qDebug() << "set to a variable the m_mono * ion charge:" << localMono;
+
   double localAvg = m_avg * abs(m_ionizeRule.charge() * m_ionizeRule.level());
 
+  qDebug() << "set to a variable the m_avg * ion charge:" << localAvg;
+
   Formula formula(m_ionizeRule.formula());
 
+  qDebug() << "The ionizerule formula:" << formula.toString();
+
   IsotopicDataCstSPtr isotopic_data_csp =
     mcsp_polChemDef->getIsotopicDataCstSPtr();
 
@@ -601,6 +640,10 @@ Ionizable::deionize()
        isotopic_data_csp, &localMono, &localAvg, -m_ionizeRule.level()))
     return -1;
 
+  qDebug() << "After having accounted the ionization formula masses into the "
+              "previously computed mono and avg masses:"
+           << localMono << "-" << localAvg;
+
   // At this point we can update the member masses;
 
   m_mono = localMono;
@@ -726,6 +769,23 @@ Ionizable::calculateMasses()
   return false;
 }
 
+QString
+Ionizable::toString()
+{
+  QString text;
+
+  text += m_ionizeRule.toString();
+  text += "\n";
+  text += Ponderable::monoString(6);
+  text += "-";
+  text += Ponderable::avgString(6);
+  text += "\n";
+  text += (m_isIonized ? "ionized" : "not ionized");
+  text += "\n";
+
+  return text;
+}
+
 } // namespace libmass
 
 } // namespace msxps
