@@ -333,17 +333,17 @@ IsotopicClusterGenerator::runIsotopicDataCalculations(
   // it by dividing all intensity that that most intense value and
   // multiplying by the requested gaussian apex intensity value.
 
-  //qDebug() << "Now asking for normalization.";
+  // qDebug() << "Now asking for normalization.";
 
   // Just a debug check.
-  //qDebug() << "Before normalizing, first data point:"
-           //<< isotopic_cluster_sp->front().toString();
+  // qDebug() << "Before normalizing, first data point:"
+  //<< isotopic_cluster_sp->front().toString();
 
   normalizeIntensities(isotopic_cluster_sp);
 
   // Just a debug check.
-  //qDebug() << "After normalizing, first data point:"
-           //<< isotopic_cluster_sp->front().toString();
+  // qDebug() << "After normalizing, first data point:"
+  //<< isotopic_cluster_sp->front().toString();
 
   // Now check if the user requests to kind of sorting of the PeakCentroid
   // instances.
@@ -397,9 +397,10 @@ IsotopicClusterGenerator::generateIsotopicClusterCentroids(
   // manual config. So we need to know how many different chemical element
   // symbols we have in the formula.
 
-  std::map<QString, int> symbol_count_map = formula.getSymbolCountMap();
+  std::map<QString, double> symbol_double_count_map =
+    formula.getSymbolCountMap();
 
-  std::size_t element_count = symbol_count_map.size();
+  std::size_t element_count = symbol_double_count_map.size();
 
   // qDebug() << "Number of different symbols in the formula:" << element_count;
 
@@ -436,8 +437,28 @@ IsotopicClusterGenerator::generateIsotopicClusterCentroids(
   double **per_element_isotope_masses_arrays_p_p = nullptr;
   double **per_element_isotope_probs_arrays_p_p  = nullptr;
 
+  // The isotopic cluster calculations do not understand
+  // formulas with double counts for the symbols!!
+  // We thus need to convert the symbol_count_map that is
+  // <QString,double>-based to a map that has its second
+  // member, not of double type but of int type.
+
+  std::map<QString, int> symbol_int_count_map;
+  std::map<QString, double>::const_iterator iter =
+    symbol_double_count_map.begin();
+
+  while(iter != symbol_double_count_map.end())
+    {
+      symbol_int_count_map[iter->first] = static_cast<int>(iter->second);
+
+      // qDebug() << "Old " << iter->first << "double version:" << iter->second
+      //          << "new int version:" << symbol_int_count_map[iter->first];
+
+               ++iter;
+    }
+
   // We pass the array pointers by reference.
-  if(!configureIsotopicData(symbol_count_map,
+  if(!configureIsotopicData(symbol_int_count_map,
                             per_element_isotopes_count_array_p,
                             per_element_symbol_count_array_p,
                             per_element_isotope_masses_arrays_p_p,
@@ -477,8 +498,8 @@ IsotopicClusterGenerator::generateIsotopicClusterCentroids(
              << formula_charge_pair.first;
 
   // Just a debug check.
-  //qDebug() << "After normalizing, first data point:"
-           //<< isotopic_cluster_sp->front().toString();
+  // qDebug() << "After normalizing, first data point:"
+  //<< isotopic_cluster_sp->front().toString();
 
   // qDebug() << "Done generating cluster for formula:"
   //<< formula_charge_pair.first;
@@ -623,7 +644,7 @@ IsotopicClusterGenerator::normalizeIntensities(
   pappso::TraceSPtr &isotopic_cluster_sp)
 {
 
-  //qDebug() << "The normalize_intensity is:" << m_normalizeIntensity;
+  // qDebug() << "The normalize_intensity is:" << m_normalizeIntensity;
 
   // The most intense peak centroid's intensity value needs to be set to the
   // requested value and the same change ratio needs to be applied to all the
@@ -632,7 +653,7 @@ IsotopicClusterGenerator::normalizeIntensities(
   // No normalization is asked for.
   if(m_normalizeIntensity == std::numeric_limits<int>::min())
     {
-      //qDebug() << "No normalization was asked for. Skipping.";
+      // qDebug() << "No normalization was asked for. Skipping.";
       return;
     }
 
@@ -662,8 +683,8 @@ IsotopicClusterGenerator::normalizeIntensities(
   if(!max_found_intensity)
     qFatal("The maximum intensity of the whole isotopic cluster is 0.");
 
-  //qDebug().noquote() << "Peak centroid with maximum intensity: "
-                     //<< vector_iterator->toString();
+  // qDebug().noquote() << "Peak centroid with maximum intensity: "
+  //<< vector_iterator->toString();
 
   // Calculate the ratio between the final requested intensity and the greatest
   // intensity. That ratio will be multiplied to intensity of the each peak
@@ -671,13 +692,13 @@ IsotopicClusterGenerator::normalizeIntensities(
 
   double intensity_factor = m_normalizeIntensity / max_found_intensity;
 
-  //qDebug() << "Will multiply this intensity factor to each data point's "
-              //"intensity value:"
-           //<< intensity_factor;
+  // qDebug() << "Will multiply this intensity factor to each data point's "
+  //"intensity value:"
+  //<< intensity_factor;
 
   // Just a debug check.
-  //qDebug() << "Before normalizing, first data point:"
-           //<< isotopic_cluster_sp->front().toString();
+  // qDebug() << "Before normalizing, first data point:"
+  //<< isotopic_cluster_sp->front().toString();
 
   std::for_each(
     isotopic_cluster_sp->begin(),
@@ -698,8 +719,8 @@ IsotopicClusterGenerator::normalizeIntensities(
   // At this point the centroids' intensity have been normalized.
 
   // Just a debug check.
-  //qDebug() << "After normalizing, first data point:"
-           //<< isotopic_cluster_sp->front().toString();
+  // qDebug() << "After normalizing, first data point:"
+  //<< isotopic_cluster_sp->front().toString();
 }
 
 
@@ -794,4 +815,3 @@ IsotopicClusterGenerator::getIsotopicClusterChargePairs() const
 } // namespace libmass
 
 } // namespace msxps
-
