@@ -584,7 +584,7 @@ IsotopicDataManualConfigHandler::writeData(const QString &file_name)
 
   QTextStream out(&file);
 
-  out << "# This file contains isotopic data in a format that can accomodate\n";
+  out << "# This file contains isotopic data in a format that can accommodate\n";
   out << "# comments in the form of lines beginning with the '#' character.\n";
 
   std::size_t isotope_count = 0;
