@@ -473,6 +473,8 @@ Modif::calculateMasses()
   m_mono = 0;
   m_avg  = 0;
 
+  qDebug() << "Right before accounting modif formula masses for formula:" << m_formula;
+
   if(!Formula::accountMasses(isotopic_data_csp, &m_mono, &m_avg))
     {
       qDebug() << "Failed accounting masses for modif:" << m_name
@@ -480,6 +482,8 @@ Modif::calculateMasses()
       return false;
     }
 
+    qDebug() << "Right after accounting modif formula masses for formula:" << m_formula << m_mono << "-" << m_avg;
+
   return true;
 }
 
