@@ -32,10 +32,6 @@
 
 
 /////////////////////// StdLib includes
-#include <IsotopicClusterGenerator.hpp>
-#include <MassPeakShaper.hpp>
-#include <MassPeakShaperConfig.hpp>
-#include <PeakCentroid.hpp>
 #include <cmath>
 #include <algorithm>
 #include <limits> // for std::numeric_limits
@@ -49,8 +45,11 @@
 /////////////////////// libmass includes
 #include <libmass/globals.hpp>
 #include <libmass/MassDataCborMassSpectrumHandler.hpp>
+#include <libmass/IsotopicClusterGenerator.hpp>
+#include <libmass/MassPeakShaper.hpp>
+#include <libmass/MassPeakShaperConfig.hpp>
+#include <libmass/PeakCentroid.hpp>
 
-#include <libmassgui/ColorSelector.hpp>
 
 
 /////////////////////// pappsomspp includes
@@ -62,6 +61,8 @@
 
 /////////////////////// Local includes
 #include "IsotopicClusterShaperDlg.hpp"
+#include "ColorSelector.hpp"
+
 
 
 namespace msxps
@@ -201,14 +202,14 @@ IsotopicClusterShaperDlg::setupDialog()
   v_box_layout_p->addWidget(mp_massPeakShaperConfigWidget);
 
   m_ui.peakShapeConfigFrame->setLayout(v_box_layout_p);
-  
+
   // Set the message timer to be singleShot. This time is used to erase the text shown in the message line edit widget after 3 seconds.
   msp_msgTimer->setInterval(3000);
   msp_msgTimer->setSingleShot(true);
   connect(msp_msgTimer.get(),
           &QTimer::timeout,
           [this] (){ m_ui.messageLineEdit->setText("");});
-  
+
   connect(m_ui.normalizationGroupBox,
           &QGroupBox::toggled,
           this,
@@ -669,7 +670,8 @@ IsotopicClusterShaperDlg::run()
   // Provide the title of the mass spectrum there for the user to have a last
   // opportunity to change it.
 
-  m_ui.massSpectrumNameResultsLineEdit->setText(m_ui.massSpectrumTitleLineEdit->text());
+  m_ui.massSpectrumNameResultsLineEdit->setText(
+    m_ui.massSpectrumTitleLineEdit->text());
 
   m_ui.tabWidget->setCurrentIndex(static_cast<int>(TabWidgetPage::RESULTS));
 }
@@ -739,25 +741,19 @@ void
 IsotopicClusterShaperDlg::traceColorPushButtonClicked()
 {
 
-  QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
-
   // Allow (true) the user to select a color that has been chosen already.
   QColor color = ColorSelector::chooseColor(true);
 
-  if(color.isValid())
-    {
-      QPalette palette = colored_push_button->palette();
-      palette.setColor(QPalette::Button, color);
-      colored_push_button->setAutoFillBackground(true);
-      colored_push_button->setPalette(palette);
-      colored_push_button->update();
+  if(!color.isValid())
+    return;
 
-      // Now prepare the color in the form of a QByteArray
+  // Store the color as a QByteArray in the member datum.
+  QDataStream stream(&m_colorByteArray, QIODevice::WriteOnly);
+  stream << color;
 
-      QDataStream stream(&m_colorByteArray, QIODevice::WriteOnly);
-
-      stream << color;
-    }
+  // Update the color of the button.
+  QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
+  colorizePushButton(colored_push_button, m_colorByteArray);
 }
 
 
@@ -816,8 +812,37 @@ void
 IsotopicClusterShaperDlg::setColorByteArray(const QByteArray &color_byte_array)
 {
   m_colorByteArray = color_byte_array;
+
+  // Update the color of the button.
+  QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
+  colorizePushButton(colored_push_button, color_byte_array);
 }
 
+void
+IsotopicClusterShaperDlg::colorizePushButton(QPushButton *push_button_p,
+                                             const QByteArray &color_byte_array)
+{
+  QColor color;
+  QDataStream stream(&m_colorByteArray, QIODevice::ReadOnly);
+  stream >> color;
+
+  if(color.isValid())
+    {
+      QPushButton *colored_push_button = m_ui.colorSelectorPushButton;
+
+      QPalette palette = colored_push_button->palette();
+      palette.setColor(QPalette::Button, color);
+      colored_push_button->setAutoFillBackground(true);
+      colored_push_button->setPalette(palette);
+      colored_push_button->update();
+
+      // Now prepare the color in the form of a QByteArray
+
+      QDataStream stream(&m_colorByteArray, QIODevice::WriteOnly);
+
+      stream << color;
+    }
+}
 
 void
 IsotopicClusterShaperDlg::importFromText()
