@@ -634,6 +634,8 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
   QString rightCode    = m_ui.rightCodeLineEdit->text();
   QString rightFormula = m_ui.rightFormulaLineEdit->text();
 
+  qDebug() << "Oh yeah! The right formula is:" << rightFormula;
+
   // If a cleaveRule is found in the list with the same name, and that
   // cleaveRule is not the one that is current in the cleaveRule list,
   // then we are making a double entry, which is not allowed.
@@ -663,26 +665,23 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
                                QMessageBox::Ok);
           return;
         }
+
+
+      libmass::Formula formula(leftFormula);
+
+      libmass::IsotopicDataSPtr isotopic_data_sp =
+        msp_polChemDef->getIsotopicDataSPtr();
+
+      if(!formula.validate(isotopic_data_sp))
+        {
+          QMessageBox::warning(this,
+                               tr("massXpert - libmass::Monomer definition"),
+                               tr("The formula failed to validate."),
+                               QMessageBox::Ok);
+          return;
+        }
     }
 
-  {
-    libmass::Formula formula(leftFormula);
-
-
-    libmass::IsotopicDataSPtr isotopic_data_sp =
-      msp_polChemDef->getIsotopicDataSPtr();
-
-    if(!formula.validate(isotopic_data_sp))
-      {
-        QMessageBox::warning(this,
-                             tr("massXpert - libmass::Monomer definition"),
-                             tr("The formula failed to validate."),
-                             QMessageBox::Ok);
-        return;
-      }
-  }
-
-
   if(!rightCode.isEmpty())
     {
       const QList<libmass::Monomer *> &monomerList =
@@ -696,24 +695,22 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
                                QMessageBox::Ok);
           return;
         }
+
+      libmass::Formula formula(rightFormula);
+
+      libmass::IsotopicDataSPtr isotopic_data_sp =
+        msp_polChemDef->getIsotopicDataSPtr();
+
+      if(!formula.validate(isotopic_data_sp))
+        {
+          QMessageBox::warning(this,
+                               tr("massXpert - libmass::Monomer definition"),
+                               tr("The formula failed to validate."),
+                               QMessageBox::Ok);
+          return;
+        }
     }
 
-  {
-    libmass::Formula formula(rightFormula);
-
-    libmass::IsotopicDataSPtr isotopic_data_sp =
-      msp_polChemDef->getIsotopicDataSPtr();
-
-    if(!formula.validate(isotopic_data_sp))
-      {
-        QMessageBox::warning(this,
-                             tr("massXpert - libmass::Monomer definition"),
-                             tr("The formula failed to validate."),
-                             QMessageBox::Ok);
-        return;
-      }
-  }
-
   cleaveRule->setName(editName);
 
   cleaveRule->setLeftCode(leftCode);
