@@ -31,24 +31,29 @@
  */
 
 /////////////////////// stdlib includes
-#include <IsotopicDataTableViewModel.hpp>
 #include <set>
 
 /////////////////////// Qt includes
-#include <IsotopicData.hpp>
-#include <IsotopicDataLibraryHandler.hpp>
-#include <IsotopicDataUserConfigHandler.hpp>
 #include <QMessageBox>
 #include <QSettings>
 #include <QFileDialog>
 #include <QTimer>
 
 
+/////////////////////// libmass includes
+#include <libmass/PolChemDef.hpp>
+#include <libmass/Isotope.hpp>
+#include <libmass/IsotopicData.hpp>
+#include <libmass/IsotopicDataLibraryHandler.hpp>
+#include <libmass/IsotopicDataUserConfigHandler.hpp>
+
+
+/////////////////////// libmassgui includes
+#include <libmassgui/IsotopicDataTableViewModel.hpp>
+
 /////////////////////// Local includes
 #include "IsotopeDefDlg.hpp"
-#include "libmass/PolChemDef.hpp"
 #include "PolChemDefWnd.hpp"
-#include "libmass/Isotope.hpp"
 
 
 namespace msxps
@@ -221,7 +226,7 @@ IsotopeDefDlg::validate()
 }
 
 // LOADING
-bool 
+bool
 IsotopeDefDlg::loadData()
 {
   // Load isotopic data from file.
