@@ -32,7 +32,6 @@
 
 
 /////////////////////// Qt includes
-#include <Oligomer.hpp>
 #include <QMessageBox>
 #include <QCloseEvent>
 #include <QDebug>
@@ -40,6 +39,10 @@
 #include <QClipboard>
 #include <QGraphicsBlurEffect>
 #include <QApplication>
+
+
+/////////////////////// libmass includes
+#include <libmass/Oligomer.hpp>
 #include <libmass/PolChemDefEntity.hpp>
 
 
