@@ -31,11 +31,15 @@
  */
 
 
+/////////////////////// libmass includes
+#include <libmass/Oligomer.hpp>
+#include <libmass/PolChemDef.hpp>
+#include <libmass/PolChemDefEntity.hpp>
+
+
 /////////////////////// Local includes
 #include "Cleaver.hpp"
-#include "libmass/PolChemDef.hpp"
-#include <Oligomer.hpp>
-#include <libmass/PolChemDefEntity.hpp>
+
 
 
 namespace msxps
