@@ -32,15 +32,16 @@
 
 
 /////////////////////// Qt includes
-#include <Oligomer.hpp>
 #include <QDebug>
 
-#include <globals.hpp>
+
+/////////////////////// libmass includes
 #include <libmass/PolChemDef.hpp>
 #include <libmass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
+#include "globals.hpp"
 #include "Fragmenter.hpp"
 #include "FragmentOligomer.hpp"
 
